@@ -16,8 +16,7 @@ extensions = [
     'sphinx.ext.extlinks',
 ]
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/2.7', None),
-    'python3': ('https://docs.python.org/3.5', None),
+    'python': ('https://docs.python.org/3', None),
 }
 source_suffix = '.rst'
 master_doc = 'index'
@@ -52,6 +51,7 @@ html_context = {
 
 html_static_path = [
     "extra.css",
+    "images/logo-small.svg",
 ]
 
 suppress_warnings = ["image.nonlocal_uri"]
