@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-
 # Copyright (C) 2006  Lukas Lalinsky
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 """Monkey's Audio streams with APEv2 tags.
 
@@ -18,10 +18,9 @@ __all__ = ["MonkeysAudio", "Open", "delete"]
 
 import struct
 
-from ._compat import endswith
 from mutagen import StreamInfo
 from mutagen.apev2 import APEv2File, error, delete
-from mutagen._util import cdata
+from mutagen._util import cdata, convert_error, endswith
 
 
 class MonkeysAudioHeaderError(error):
@@ -29,18 +28,22 @@ class MonkeysAudioHeaderError(error):
 
 
 class MonkeysAudioInfo(StreamInfo):
-    """Monkey's Audio stream information.
+    """MonkeysAudioInfo()
+
+    Monkey's Audio stream information.
 
     Attributes:
-
-    * channels -- number of audio channels
-    * length -- file length in seconds, as a float
-    * sample_rate -- audio sampling rate in Hz
-    * bits_per_sample -- bits per sample
-    * version -- Monkey's Audio stream version, as a float (eg: 3.99)
+        channels (`int`): number of audio channels
+        length (`float`): file length in seconds, as a float
+        sample_rate (`int`): audio sampling rate in Hz
+        bits_per_sample (`int`): bits per sample
+        version (`float`): Monkey's Audio stream version, as a float (eg: 3.99)
     """
 
+    @convert_error(IOError, MonkeysAudioHeaderError)
     def __init__(self, fileobj):
+        """Raises MonkeysAudioHeaderError"""
+
         header = fileobj.read(76)
         if len(header) != 76 or not header.startswith(b"MAC "):
             raise MonkeysAudioHeaderError("not a Monkey's Audio file")
@@ -62,6 +65,9 @@ class MonkeysAudioInfo(StreamInfo):
                 blocks_per_frame = 73728
             else:
                 blocks_per_frame = 9216
+            self.bits_per_sample = 0
+            if header[48:].startswith(b"WAVEfmt"):
+                self.bits_per_sample = struct.unpack("<H", header[74:76])[0]
         self.version /= 1000.0
         self.length = 0.0
         if (self.sample_rate != 0) and (total_frames > 0):
@@ -75,6 +81,15 @@ class MonkeysAudioInfo(StreamInfo):
 
 
 class MonkeysAudio(APEv2File):
+    """MonkeysAudio(filething)
+
+    Arguments:
+        filething (filething)
+
+    Attributes:
+        info (`MonkeysAudioInfo`)
+    """
+
     _Info = MonkeysAudioInfo
     _mimes = ["audio/ape", "audio/x-ape"]
 
