@@ -10,17 +10,16 @@
 
 True Audio is a lossless format designed for real-time encoding and
 decoding. This module is based on the documentation at
-http://www.true-audio.com/TTA_Lossless_Audio_Codec\_-_Format_Description
+http://www.true-audio.com/TTA_Lossless_Audio_Codec\\_-_Format_Description
 
 True Audio files use ID3 tags.
 """
 
 __all__ = ["TrueAudio", "Open", "delete", "EasyTrueAudio"]
 
-from ._compat import endswith
 from mutagen import StreamInfo
 from mutagen.id3 import ID3FileType, delete
-from mutagen._util import cdata, MutagenError, convert_error
+from mutagen._util import cdata, MutagenError, convert_error, endswith
 
 
 class error(MutagenError):
