@@ -3,11 +3,12 @@
 import os
 import subprocess
 
+import pytest
+
 from mutagen import MutagenError
 from mutagen.id3 import ID3, TIT2, ID3NoHeaderError
 from mutagen.flac import to_int_be, Padding, VCFLACDict, MetadataBlock, error
 from mutagen.flac import StreamInfo, SeekTable, CueSheet, FLAC, delete, Picture
-from mutagen._compat import PY3
 
 from tests import TestCase, DATA_DIR, get_temp_copy
 from tests.test__vorbis import TVCommentDict, VComment
@@ -355,6 +356,19 @@ class TFLAC(TestCase):
         flac = FLAC(self.NEW)
         self.assertTrue(flac.tags is None)
 
+    def test_delete_change_reload(self):
+        self.flac.delete()
+        self.flac.tags["FOO"] = ["BAR"]
+        self.flac.save()
+        assert FLAC(self.flac.filename)["FOO"] == ["BAR"]
+
+        # same with delete failing due to IO etc.
+        with pytest.raises(MutagenError):
+            self.flac.delete(os.devnull)
+        self.flac.tags["FOO"] = ["QUUX"]
+        self.flac.save()
+        assert FLAC(self.flac.filename)["FOO"] == ["QUUX"]
+
     def test_module_delete(self):
         delete(self.NEW)
         flac = FLAC(self.NEW)
@@ -387,35 +401,18 @@ class TFLAC(TestCase):
 
     def test_write_changetitle(self):
         f = FLAC(self.NEW)
-        if PY3:
-            self.assertRaises(
-                TypeError, f.__setitem__, b'title', b"A New Title")
-        else:
-            f[b"title"] = b"A New Title"
-            f.save()
-            f = FLAC(self.NEW)
-            self.failUnlessEqual(f[b"title"][0], b"A New Title")
+        self.assertRaises(
+            TypeError, f.__setitem__, b'title', b"A New Title")
 
     def test_write_changetitle_unicode_value(self):
         f = FLAC(self.NEW)
-        if PY3:
-            self.assertRaises(
-                TypeError, f.__setitem__, b'title', u"A Unicode Title \u2022")
-        else:
-            f[b"title"] = u"A Unicode Title \u2022"
-            f.save()
-            f = FLAC(self.NEW)
-            self.failUnlessEqual(f[b"title"][0], u"A Unicode Title \u2022")
+        self.assertRaises(
+            TypeError, f.__setitem__, b'title', u"A Unicode Title \u2022")
 
     def test_write_changetitle_unicode_key(self):
         f = FLAC(self.NEW)
         f[u"title"] = b"A New Title"
-        if PY3:
-            self.assertRaises(ValueError, f.save)
-        else:
-            f.save()
-            f = FLAC(self.NEW)
-            self.failUnlessEqual(f[u"title"][0], b"A New Title")
+        self.assertRaises(ValueError, f.save)
 
     def test_write_changetitle_unicode_key_and_value(self):
         f = FLAC(self.NEW)
@@ -572,7 +569,7 @@ class TFLACFile(TestCase):
 
     def test_open_nonexistant(self):
         """mutagen 1.2 raises UnboundLocalError, then it tries to open
-        non-existant FLAC files"""
+        non-existent FLAC files"""
         filename = os.path.join(DATA_DIR, "doesntexist.flac")
         self.assertRaises(MutagenError, FLAC, filename)
 
@@ -619,6 +616,56 @@ class TFLACBadBlockSizeWrite(TestCase):
         self.failIf(b"Tunng" in data)
 
 
+class TFLACBadDuplicateVorbisComment(TestCase):
+
+    def setUp(self):
+        self.filename = get_temp_copy(
+            os.path.join(DATA_DIR, "silence-44-s.flac"))
+
+        # add a second vorbis comment block to the file right after the first
+        some_tags = VCFLACDict()
+        some_tags["DUPLICATE"] = ["SECOND"]
+        f = FLAC(self.filename)
+        f.tags["DUPLICATE"] = ["FIRST"]
+        assert f.tags is f.metadata_blocks[2]
+        f.metadata_blocks.insert(3, some_tags)
+        f.save()
+
+    def tearDown(self):
+        os.unlink(self.filename)
+
+    def test_load_multiple(self):
+        # on load always use the first one, like metaflac
+        f = FLAC(self.filename)
+        assert f["DUPLICATE"] == ["FIRST"]
+        assert f.metadata_blocks[2] is f.tags
+        assert f.metadata_blocks[3]["DUPLICATE"] == ["SECOND"]
+
+        # save in the same order
+        f.save()
+        f = FLAC(self.filename)
+        assert f["DUPLICATE"] == ["FIRST"]
+
+    def test_delete_multiple(self):
+        # on delete we delete both
+        f = FLAC(self.filename)
+        f.delete()
+        assert len(f.tags) == 0
+        f = FLAC(self.filename)
+        assert f.tags is None
+
+    def test_delete_multiple_fail(self):
+        f = FLAC(self.filename)
+        with pytest.raises(MutagenError):
+            f.delete(os.devnull)
+        f.save()
+
+        # if delete failed we shouldn't see a difference
+        f = FLAC(self.filename)
+        assert f.metadata_blocks[2] is f.tags
+        assert f.metadata_blocks[3].code == f.tags.code
+
+
 class TFLACBadBlockSizeOverflow(TestCase):
 
     def setUp(self):
