@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import os
+from io import BytesIO
 
 from mutagen import id3
 from mutagen import MutagenError
@@ -14,7 +15,6 @@ from mutagen.id3._util import BitPaddedInt, error as ID3Error
 from mutagen.id3._tags import determine_bpi, ID3Header, \
     save_frame, ID3SaveConfig
 from mutagen.id3._id3v1 import find_id3v1
-from mutagen._compat import cBytesIO, xrange
 
 from tests import TestCase, DATA_DIR, get_temp_copy, get_temp_empty
 
@@ -30,9 +30,11 @@ class TID3Read(TestCase):
 
     empty = os.path.join(DATA_DIR, 'emptyfile.mp3')
     silence = os.path.join(DATA_DIR, 'silence-44-s.mp3')
+    silence_v1 = os.path.join(DATA_DIR, 'silence-44-s-v1.mp3')
     unsynch = os.path.join(DATA_DIR, 'id3v23_unsynch.id3')
     v22 = os.path.join(DATA_DIR, "id3v22-test.mp3")
     bad_tyer = os.path.join(DATA_DIR, 'bad-TYER-frame.mp3')
+    v1v2_combined = os.path.join(DATA_DIR, "id3v1v2-combined.mp3")
 
     def test_PIC_in_23(self):
         filename = get_temp_empty(".mp3")
@@ -112,6 +114,95 @@ class TID3Read(TestCase):
         self.failUnless(tags["TRCK"].text == ["3/11"])
         self.failUnless(tags["TPE1"].text == ["Anais Mitchell"])
 
+    def test_load_v1(self):
+        tags = ID3(self.silence_v1)
+        self.assertEquals(tags["TALB"], "Quod Libet Test Data")
+
+        with self.assertRaises(ID3NoHeaderError):
+            tags = ID3(self.silence_v1, load_v1=False)
+
+    def test_load_v1_v2(self):
+        tags = ID3(self.v1v2_combined)
+        # From ID3v2
+        self.assertEquals(tags["TPE1"].text, ["Anais Mitchell"])
+        # From ID3v1
+        self.assertEquals(tags["TALB"].text, ["Hymns for the Exiled"])
+
+        tags = ID3(self.v1v2_combined, load_v1=False)
+        self.assertEquals(tags["TPE1"].text, ["Anais Mitchell"])
+        with self.assertRaises(KeyError):
+            tags["TALB"]
+
+    def test_load_v1_v2_no_translate(self):
+        tags = ID3(self.v1v2_combined, v2_version=4, translate=False)
+        assert tags.version == (2, 4, 0)
+        assert str(tags["TDRC"].text[0]) == "1337"
+        tags = ID3(self.v1v2_combined, v2_version=3, translate=False)
+        assert tags.version == (2, 4, 0)
+        assert str(tags["TDRC"].text[0]) == "1337"
+
+    def test_load_v1_v2_tcon_translate(self):
+        tags = ID3()
+        tags.add(TCON(text=["12"]))
+        v1_data = MakeID3v1(tags)
+
+        filename = get_temp_copy(self.empty)
+        try:
+            tags = ID3()
+            tags.save(filename=filename, v1=0)
+            with open(filename, "ab") as h:
+                h.write(v1_data)
+            tags = ID3(filename, load_v1=True)
+            assert tags["TCON"][0] == "Other"
+            tags = ID3(filename, load_v1=False)
+            assert "TCON" not in tags
+        finally:
+            os.unlink(filename)
+
+    def test_load_v1_v2_precedence(self):
+        tags = ID3(self.v1v2_combined)
+        self.assertEquals(tags["TRCK"].text, ["3/11"])  # i.e. not 123
+
+        # ID3v2 has TYER=2004 (which isn't a valid v2.4 frame),
+        # ID3v1 has TDRC=1337.
+        self.assertEquals(str(tags["TDRC"].text[0]), "1337")
+        with self.assertRaises(KeyError):
+            tags["TYER"]
+
+        tags = ID3(self.v1v2_combined, v2_version=3)
+
+        # With v2_version=3, the ID3v2 tag should still have precedence
+        self.assertEquals(str(tags["TYER"].text[0]), "2004")
+        with self.assertRaises(KeyError):
+            tags["TDRC"]
+
+    def test_load_v1_comment(self):
+        # Tags with different HashKeys but equal FrameIDs (like COMM)
+        # should be kept separate
+        tags = ID3(self.v1v2_combined)
+        comments = tags.getall("COMM")
+        # From ID3v2
+        self.failUnless("Waterbug Records, www.anaismitchell.com" in comments)
+        # From ID3v1
+        self.failUnless("v1 comment" in comments)
+
+    def test_load_v1_known_frames_override(self):
+        class MyCOMM(COMM):
+            @property
+            def FrameID(self):
+                # We want to replace the existing COMM, so override
+                # the FrameID
+                return COMM.__name__
+
+        frames = dict(id3.Frames)
+        frames["COMM"] = MyCOMM
+        tags = ID3(self.v1v2_combined, known_frames=frames)
+
+        comments = tags.getall("COMM")
+        self.failUnless(len(comments) > 0)
+        for comm in comments:
+            self.assertIsInstance(comm, MyCOMM)
+
     def test_empty_file(self):
         self.assertRaises(ID3Error, ID3, filename=self.empty)
 
@@ -235,6 +326,16 @@ class TID3Read(TestCase):
         id3.update_to_v24()
         self.failUnlessEqual(id3["TDRC"], "2006-03-06 11:27:00")
 
+    def test_multiple_tyer_tdat_time(self):
+        id3 = ID3()
+        id3.version = (2, 3)
+        id3.add(TYER(text=['2000', '2001', '2002', '19xx', 'foo']))
+        id3.add(TDAT(text=['0102', '0304', '1111bar']))
+        id3.add(TIME(text=['1220', '1111quux', '1111']))
+        id3.update_to_v24()
+        assert [str(t) for t in id3['TDRC']] == \
+            ['2000-02-01 12:20:00', '2001-04-03', '2002']
+
     def test_tory(self):
         id3 = ID3()
         id3.version = (2, 3)
@@ -280,60 +381,60 @@ class TID3Header(TestCase):
         self.assertEquals(header.size, 1314)
 
     def test_header_2_4_invalid_flags(self):
-        fileobj = cBytesIO(b'ID3\x04\x00\x1f\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x04\x00\x1f\x00\x00\x00\x00')
         self.assertRaises(ID3Error, ID3Header, fileobj)
 
     def test_header_2_4_unsynch_size(self):
-        fileobj = cBytesIO(b'ID3\x04\x00\x10\x00\x00\x00\xFF')
+        fileobj = BytesIO(b'ID3\x04\x00\x10\x00\x00\x00\xFF')
         self.assertRaises(ID3Error, ID3Header, fileobj)
 
     def test_header_2_4_allow_footer(self):
-        fileobj = cBytesIO(b'ID3\x04\x00\x10\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x04\x00\x10\x00\x00\x00\x00')
         self.assertTrue(ID3Header(fileobj).f_footer)
 
     def test_header_2_3_invalid_flags(self):
-        fileobj = cBytesIO(b'ID3\x03\x00\x1f\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x03\x00\x1f\x00\x00\x00\x00')
         self.assertRaises(ID3Error, ID3Header, fileobj)
 
-        fileobj = cBytesIO(b'ID3\x03\x00\x0f\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x03\x00\x0f\x00\x00\x00\x00')
         self.assertRaises(ID3Error, ID3Header, fileobj)
 
     def test_header_2_2(self):
-        fileobj = cBytesIO(b'ID3\x02\x00\x00\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x02\x00\x00\x00\x00\x00\x00')
         header = ID3Header(fileobj)
         self.assertEquals(header.version, (2, 2, 0))
 
     def test_header_2_1(self):
-        fileobj = cBytesIO(b'ID3\x01\x00\x00\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x01\x00\x00\x00\x00\x00\x00')
         self.assertRaises(ID3UnsupportedVersionError, ID3Header, fileobj)
 
     def test_header_too_small(self):
-        fileobj = cBytesIO(b'ID3\x01\x00\x00\x00\x00\x00')
+        fileobj = BytesIO(b'ID3\x01\x00\x00\x00\x00\x00')
         self.assertRaises(ID3Error, ID3Header, fileobj)
 
     def test_header_2_4_extended(self):
-        fileobj = cBytesIO(
+        fileobj = BytesIO(
             b'ID3\x04\x00\x40\x00\x00\x00\x00\x00\x00\x00\x05\x5a')
         header = ID3Header(fileobj)
         self.assertEquals(header._extdata, b'\x5a')
 
     def test_header_2_4_extended_unsynch_size(self):
-        fileobj = cBytesIO(
+        fileobj = BytesIO(
             b'ID3\x04\x00\x40\x00\x00\x00\x00\x00\x00\x00\xFF\x5a')
         self.assertRaises(ID3Error, ID3Header, fileobj)
 
     def test_header_2_4_extended_but_not(self):
-        fileobj = cBytesIO(
+        fileobj = BytesIO(
             b'ID3\x04\x00\x40\x00\x00\x00\x00TIT1\x00\x00\x00\x01a')
         header = ID3Header(fileobj)
         self.assertEquals(header._extdata, b'')
 
     def test_header_2_4_extended_but_not_but_not_tag(self):
-        fileobj = cBytesIO(b'ID3\x04\x00\x40\x00\x00\x00\x00TIT9')
+        fileobj = BytesIO(b'ID3\x04\x00\x40\x00\x00\x00\x00TIT9')
         self.failUnlessRaises(ID3Error, ID3Header, fileobj)
 
     def test_header_2_3_extended(self):
-        fileobj = cBytesIO(
+        fileobj = BytesIO(
             b'ID3\x03\x00\x40\x00\x00\x00\x00\x00\x00\x00\x06'
             b'\x00\x00\x56\x78\x9a\xbc')
         header = ID3Header(fileobj)
@@ -371,7 +472,7 @@ class TID3Tags(TestCase):
 
     def test_apic_duplicate_hash(self):
         id3 = ID3Tags()
-        for i in xrange(10):
+        for i in range(10):
             apic = APIC(encoding=0, mime=u"b", type=3, desc=u"", data=b"a")
             id3._add(apic, False)
 
@@ -1047,7 +1148,7 @@ class Issue69_BadV1Year(TestCase):
         self.failUnlessEqual(tag["TIT2"], "hello world")
         self.failUnlessEqual(tag["TDRC"], "0001")
 
-        frames, offset = find_id3v1(cBytesIO(data))
+        frames, offset = find_id3v1(BytesIO(data))
         self.assertEqual(offset, -125)
         self.assertEqual(frames, tag)
 
