@@ -3,8 +3,10 @@
 import os
 import struct
 import subprocess
+from io import BytesIO
+
+import pytest
 
-from mutagen._compat import cBytesIO, PY3, text_type, PY2, izip
 from tests import TestCase, DATA_DIR, get_temp_copy
 from mutagen.mp4 import (MP4, Atom, Atoms, MP4Tags, MP4Info, delete, MP4Cover,
                          MP4MetadataError, MP4FreeForm, error, AtomDataType,
@@ -17,29 +19,29 @@ from mutagen._util import cdata
 class TAtom(TestCase):
 
     def test_no_children(self):
-        fileobj = cBytesIO(b"\x00\x00\x00\x08atom")
+        fileobj = BytesIO(b"\x00\x00\x00\x08atom")
         atom = Atom(fileobj)
         self.failUnlessRaises(KeyError, atom.__getitem__, "test")
 
     def test_length_1(self):
-        fileobj = cBytesIO(b"\x00\x00\x00\x01atom"
-                           b"\x00\x00\x00\x00\x00\x00\x00\x10" + b"\x00" * 16)
+        fileobj = BytesIO(b"\x00\x00\x00\x01atom"
+                          b"\x00\x00\x00\x00\x00\x00\x00\x10" + b"\x00" * 16)
         atom = Atom(fileobj)
         self.failUnlessEqual(atom.length, 16)
         self.failUnlessEqual(atom.datalength, 0)
 
     def test_length_64bit_less_than_16(self):
-        fileobj = cBytesIO(b"\x00\x00\x00\x01atom"
-                           b"\x00\x00\x00\x00\x00\x00\x00\x08" + b"\x00" * 8)
+        fileobj = BytesIO(b"\x00\x00\x00\x01atom"
+                          b"\x00\x00\x00\x00\x00\x00\x00\x08" + b"\x00" * 8)
         self.assertRaises(AtomError, Atom, fileobj)
 
     def test_length_less_than_8(self):
-        fileobj = cBytesIO(b"\x00\x00\x00\x02atom")
+        fileobj = BytesIO(b"\x00\x00\x00\x02atom")
         self.assertRaises(AtomError, Atom, fileobj)
 
     def test_truncated(self):
-        self.assertRaises(AtomError, Atom, cBytesIO(b"\x00"))
-        self.assertRaises(AtomError, Atom, cBytesIO(b"\x00\x00\x00\x01atom"))
+        self.assertRaises(AtomError, Atom, BytesIO(b"\x00"))
+        self.assertRaises(AtomError, Atom, BytesIO(b"\x00\x00\x00\x01atom"))
 
     def test_render_too_big(self):
         class TooBig(bytes):
@@ -56,19 +58,19 @@ class TAtom(TestCase):
             self.failUnlessEqual(len(data), 4 + 4 + 8 + 4)
 
     def test_non_top_level_length_0_is_invalid(self):
-        data = cBytesIO(struct.pack(">I4s", 0, b"whee"))
+        data = BytesIO(struct.pack(">I4s", 0, b"whee"))
         self.assertRaises(AtomError, Atom, data, level=1)
 
     def test_length_0(self):
-        fileobj = cBytesIO(b"\x00\x00\x00\x00atom" + 40 * b"\x00")
+        fileobj = BytesIO(b"\x00\x00\x00\x00atom" + 40 * b"\x00")
         atom = Atom(fileobj)
         self.failUnlessEqual(fileobj.tell(), 48)
         self.failUnlessEqual(atom.length, 48)
         self.failUnlessEqual(atom.datalength, 40)
 
     def test_length_0_container(self):
-        data = cBytesIO(struct.pack(">I4s", 0, b"moov") +
-                        Atom.render(b"data", b"whee"))
+        data = BytesIO(struct.pack(">I4s", 0, b"moov") +
+                       Atom.render(b"data", b"whee"))
         atom = Atom(data)
         self.failUnlessEqual(len(atom.children), 1)
         self.failUnlessEqual(atom.length, 20)
@@ -76,14 +78,14 @@ class TAtom(TestCase):
 
     def test_read(self):
         payload = 8 * b"\xff"
-        fileobj = cBytesIO(b"\x00\x00\x00\x10atom" + payload)
+        fileobj = BytesIO(b"\x00\x00\x00\x10atom" + payload)
         atom = Atom(fileobj)
         ok, data = atom.read(fileobj)
         self.assertTrue(ok)
         self.assertEqual(data, payload)
 
         payload = 7 * b"\xff"
-        fileobj = cBytesIO(b"\x00\x00\x00\x10atom" + payload)
+        fileobj = BytesIO(b"\x00\x00\x00\x10atom" + payload)
         atom = Atom(fileobj)
         ok, data = atom.read(fileobj)
         self.assertFalse(ok)
@@ -117,7 +119,7 @@ class TAtoms(TestCase):
         self.failUnless(self.atoms.atoms[0].children is None)
 
     def test_extra_trailing_data(self):
-        data = cBytesIO(Atom.render(b"data", b"whee") + b"\x00\x00")
+        data = BytesIO(Atom.render(b"data", b"whee") + b"\x00\x00")
         self.failUnless(Atoms(data))
 
     def test_repr(self):
@@ -138,7 +140,7 @@ class TMP4Info(TestCase):
         mdia = Atom.render(b"mdia", mdhd + hdlr)
         trak = Atom.render(b"trak", mdia)
         moov = Atom.render(b"moov", trak)
-        fileobj = cBytesIO(moov)
+        fileobj = BytesIO(moov)
         atoms = Atoms(fileobj)
         info = MP4Info(atoms, fileobj)
         self.failUnlessEqual(info.length, 8)
@@ -154,14 +156,14 @@ class TMP4Info(TestCase):
         mdia = Atom.render(b"mdia", mdhd + hdlr)
         trak2 = Atom.render(b"trak", mdia)
         moov = Atom.render(b"moov", trak1 + trak2)
-        fileobj = cBytesIO(moov)
+        fileobj = BytesIO(moov)
         atoms = Atoms(fileobj)
         info = MP4Info(atoms, fileobj)
         self.failUnlessEqual(info.length, 8)
 
     def test_no_tracks(self):
         moov = Atom.render(b"moov", b"")
-        fileobj = cBytesIO(moov)
+        fileobj = BytesIO(moov)
         atoms = Atoms(fileobj)
         with self.assertRaises(MP4StreamInfoError):
             MP4Info(atoms, fileobj)
@@ -173,7 +175,7 @@ class TMP4Tags(TestCase):
         ilst = Atom.render(b"ilst", data)
         meta = Atom.render(b"meta", b"\x00" * 4 + ilst)
         data = Atom.render(b"moov", Atom.render(b"udta", meta))
-        fileobj = cBytesIO(data)
+        fileobj = BytesIO(data)
         return MP4Tags(Atoms(fileobj), fileobj)
 
     def test_parse_multiple_atoms(self):
@@ -272,6 +274,17 @@ class TMP4Tags(TestCase):
             b"\x00\x00\x00\x15\x00\x00\x00\x00\x00"
         )
 
+    def test_render_integer_min_size(self):
+        render_int = MP4Tags()._MP4Tags__render_integer
+
+        data = render_int('stik', [42], 1)
+        tags = self.wrap_ilst(data)
+        assert tags['stik'] == [42]
+
+        assert len(render_int('stik', [42], 2)) == len(data) + 1
+        assert len(render_int('stik', [42], 4)) == len(data) + 3
+        assert len(render_int('stik', [42], 8)) == len(data) + 7
+
     def test_render_text(self):
         self.failUnlessEqual(
             MP4Tags()._MP4Tags__render_text(
@@ -556,8 +569,7 @@ class TMP4Mixin(object):
             self.set_key('\xa9nam', [b'\xe3\x82\x8a\xe3\x81\x8b'],
                          result=[u'\u308a\u304b'])
         except TypeError:
-            if not PY3:
-                raise
+            pass
 
     def test_preserve_freeform(self):
         self.set_key('----:net.sacredchao.Mutagen:test key',
@@ -634,8 +646,8 @@ class TMP4Mixin(object):
 
     def test_various_int(self):
         keys = [
-            "stik", "rtng", "plID", "cnID", "geID", "atID", "sfID",
-            "cmID", "akID", "tvsn", "tves",
+            "stik", "hdvd", "rtng", "plID", "cnID", "geID", "atID",
+            "sfID", "cmID", "akID", "tvsn", "tves",
         ]
 
         for key in keys:
@@ -695,7 +707,7 @@ class TMP4Mixin(object):
 
     def test_pprint(self):
         self.failUnless(self.audio.pprint())
-        self.assertTrue(isinstance(self.audio.pprint(), text_type))
+        self.assertTrue(isinstance(self.audio.pprint(), str))
 
     def test_pprint_binary(self):
         self.audio["covr"] = [b"\x00\xa9garbage"]
@@ -759,7 +771,7 @@ class TMP4Mixin(object):
         self.audio["\xa9nam"] = "wheeeeeeee"
         self.audio.save()
         bb = self.__read_offsets(self.filename)
-        for a, b in izip(aa, bb):
+        for a, b in zip(aa, bb):
             self.failUnlessEqual(a, b)
 
     def test_mime(self):
@@ -960,7 +972,7 @@ class TMP4Misc(TestCase):
 
     def test_no_audio_tracks(self):
         data = Atom.render(b"moov", Atom.render(b"udta", b""))
-        fileobj = cBytesIO(data)
+        fileobj = BytesIO(data)
         audio = MP4(fileobj)
         assert audio.info
         assert audio.pprint()
@@ -970,8 +982,8 @@ class TMP4Misc(TestCase):
         assert isinstance(info.channels, int)
         assert isinstance(info.sample_rate, int)
         assert isinstance(info.bits_per_sample, int)
-        assert isinstance(info.codec, text_type)
-        assert isinstance(info.codec_description, text_type)
+        assert isinstance(info.codec, str)
+        assert isinstance(info.codec_description, str)
 
     def test_parse_full_atom(self):
         p = parse_full_atom(b"\x01\x02\x03\x04\xff")
@@ -1006,9 +1018,6 @@ class TMP4Freeform(TestCase):
     def test_cmp_bytes(self):
         self.assertReallyEqual(MP4FreeForm(b'woooo'), b"woooo")
         self.assertReallyNotEqual(MP4FreeForm(b'woooo'), b"foo")
-        if PY2:
-            self.assertReallyEqual(MP4FreeForm(b'woooo'), u"woooo")
-            self.assertReallyNotEqual(MP4FreeForm(b'woooo'), u"foo")
 
 
 class TMP4Cover(TestCase):
@@ -1024,9 +1033,6 @@ class TMP4Cover(TestCase):
     def test_cmp_bytes(self):
         self.assertReallyEqual(MP4Cover(b'woooo'), b"woooo")
         self.assertReallyNotEqual(MP4Cover(b'woooo'), b"foo")
-        if PY2:
-            self.assertReallyEqual(MP4Cover(b'woooo'), u"woooo")
-            self.assertReallyNotEqual(MP4Cover(b'woooo'), u"foo")
 
 
 class TMP4AudioSampleEntry(TestCase):
@@ -1040,7 +1046,7 @@ class TMP4AudioSampleEntry(TestCase):
             b'\x00\x00\x00\x00$alac\x00\x00\x00\x00\x00\x00\x10\x00\x00\x10'
             b'(\n\x0e\x01\x00\xff\x00\x00P\x01\x00\x00\x00\x00\x00\x00\x1f@')
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
         self.assertEqual(entry.bitrate, 0)
@@ -1058,7 +1064,7 @@ class TMP4AudioSampleEntry(TestCase):
             b'\x00\x00\x00\x00$alac\x00\x00\x00\x00\x00\x00\x10\x00\x00\x18'
             b'(\n\x0e\x02\x00\xff\x00\x00F/\x00%2\xd5\x00\x01X\x88')
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
         self.assertEqual(entry.bitrate, 2437845)
@@ -1076,7 +1082,7 @@ class TMP4AudioSampleEntry(TestCase):
             b'\x03k\x00\x05\x80\x80\x80\x0f+\x01\x88\x02\xc4\x04\x90,\x10\x8c'
             b'\x80\x00\x00\xed@\x06\x80\x80\x80\x01\x02')
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
 
@@ -1096,7 +1102,7 @@ class TMP4AudioSampleEntry(TestCase):
             b"\xda\xc0\x05\x80\x80\x80\x07\x13\x08V\xe5\x9dH\x80\x06\x80\x80"
             b"\x80\x01\x02")
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
 
@@ -1107,8 +1113,8 @@ class TMP4AudioSampleEntry(TestCase):
         self.assertEqual(entry.sample_rate, 48000)
         self.assertEqual(entry.sample_size, 16)
 
-        self.assertTrue(isinstance(entry.codec, text_type))
-        self.assertTrue(isinstance(entry.codec_description, text_type))
+        self.assertTrue(isinstance(entry.codec, str))
+        self.assertTrue(isinstance(entry.codec_description, str))
 
     def test_als(self):
         atom_data = (
@@ -1121,7 +1127,7 @@ class TMP4AudioSampleEntry(TestCase):
             b'\x10\x00\x00\x00\x01\x00\x00\x02\xd0\x07\x00\x00\x00@\x1f\x00'
             b'\x00\x04\x10\x00data\x00$0\x00\xf6\xceF+\x06\x01\x02')
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
 
@@ -1138,7 +1144,7 @@ class TMP4AudioSampleEntry(TestCase):
             b'\x00\x00\x00\x00\x00\x00\x02\x00\x10\x00\x00\x00\x00V"\x00\x00'
             b'\x00\x00\x00\x0bdac3R\t\x00')
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
 
@@ -1149,8 +1155,8 @@ class TMP4AudioSampleEntry(TestCase):
         self.assertEqual(entry.sample_rate, 22050)
         self.assertEqual(entry.sample_size, 16)
 
-        self.assertTrue(isinstance(entry.codec, text_type))
-        self.assertTrue(isinstance(entry.codec_description, text_type))
+        self.assertTrue(isinstance(entry.codec, str))
+        self.assertTrue(isinstance(entry.codec_description, str))
 
     def test_samr(self):
         # parsing not implemented, values are wrong but at least it loads.
@@ -1160,7 +1166,7 @@ class TMP4AudioSampleEntry(TestCase):
             b'\x00\x00\x00\x00\x00\x00\x02\x00\x10\x00\x00\x00\x00\x1f@\x00'
             b'\x00\x00\x00\x00\x11damrFFMP\x00\x81\xff\x00\x01')
 
-        fileobj = cBytesIO(atom_data)
+        fileobj = BytesIO(atom_data)
         atom = Atom(fileobj)
         entry = AudioSampleEntry(atom, fileobj)
 
@@ -1171,15 +1177,42 @@ class TMP4AudioSampleEntry(TestCase):
         self.assertEqual(entry.sample_rate, 8000)
         self.assertEqual(entry.sample_size, 16)
 
-        self.assertTrue(isinstance(entry.codec, text_type))
-        self.assertTrue(isinstance(entry.codec_description, text_type))
+        self.assertTrue(isinstance(entry.codec, str))
+        self.assertTrue(isinstance(entry.codec_description, str))
 
     def test_error(self):
-        fileobj = cBytesIO(b"\x00" * 20)
+        fileobj = BytesIO(b"\x00" * 20)
         atom = Atom(fileobj)
         self.assertRaises(ASEntryError, AudioSampleEntry, atom, fileobj)
 
 
+def test_weird_descriptor_size():
+    path = os.path.join(DATA_DIR, "ep7.m4b")
+    t = MP4(path)
+    assert t.info.length == pytest.approx(2.02, 2)
+    assert t.info.bitrate == 125591
+    assert t.info.sample_rate == 44100
+    assert t.info.codec_description == "AAC LC"
+
+    path = os.path.join(DATA_DIR, "ep9.m4b")
+    t = MP4(path)
+    assert t.info.length == pytest.approx(2.02, 2)
+    assert t.info.bitrate == 61591
+    assert t.info.sample_rate == 44100
+    assert t.info.codec_description == "AAC LC"
+
+
+class TMP4Chapters(TMP4):
+    original = os.path.join(DATA_DIR, "nero-chapters.m4b")
+
+    def test_has_chapters(self):
+        self.failUnless(hasattr(self.audio, 'chapters'))
+        chapters = self.audio.chapters
+        self.failUnlessEqual(len(chapters), 112)
+        for i, c in enumerate(chapters):
+            self.failUnlessEqual(c.title, str(i + 1).zfill(3))
+
+
 def call_faad(*args):
     with open(os.devnull, 'wb') as null:
         return subprocess.call(
