@@ -2,23 +2,20 @@
 
 import os
 import shutil
+from io import BytesIO
 
-from mutagen._compat import cBytesIO
 from mutagen.ogg import OggPage
-from mutagen.oggvorbis import OggVorbis, OggVorbisInfo, delete
-from tests import TestCase, DATA_DIR
+from mutagen.oggvorbis import OggVorbis, OggVorbisInfo, delete, error
+
+from tests import TestCase, DATA_DIR, get_temp_copy
 from tests.test_ogg import TOggFileTypeMixin
-from tempfile import mkstemp
 
 
 class TOggVorbis(TestCase, TOggFileTypeMixin):
     Kind = OggVorbis
 
     def setUp(self):
-        original = os.path.join(DATA_DIR, "empty.ogg")
-        fd, self.filename = mkstemp(suffix='.ogg')
-        os.close(fd)
-        shutil.copy(original, self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, "empty.ogg"))
         self.audio = self.Kind(self.filename)
 
     def tearDown(self):
@@ -39,44 +36,49 @@ class TOggVorbis(TestCase, TOggFileTypeMixin):
         self.failUnlessEqual(44100, self.audio.info.sample_rate)
 
     def test_invalid_not_first(self):
-        page = OggPage(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            page = OggPage(h)
         page.first = False
-        self.failUnlessRaises(IOError, OggVorbisInfo, cBytesIO(page.write()))
+        self.failUnlessRaises(error, OggVorbisInfo, BytesIO(page.write()))
 
     def test_avg_bitrate(self):
-        page = OggPage(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            page = OggPage(h)
         packet = page.packets[0]
         packet = (packet[:16] + b"\x00\x00\x01\x00" + b"\x00\x00\x00\x00" +
                   b"\x00\x00\x00\x00" + packet[28:])
         page.packets[0] = packet
-        info = OggVorbisInfo(cBytesIO(page.write()))
+        info = OggVorbisInfo(BytesIO(page.write()))
         self.failUnlessEqual(info.bitrate, 32768)
 
     def test_overestimated_bitrate(self):
-        page = OggPage(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            page = OggPage(h)
         packet = page.packets[0]
         packet = (packet[:16] + b"\x00\x00\x01\x00" + b"\x00\x00\x00\x01" +
                   b"\x00\x00\x00\x00" + packet[28:])
         page.packets[0] = packet
-        info = OggVorbisInfo(cBytesIO(page.write()))
+        info = OggVorbisInfo(BytesIO(page.write()))
         self.failUnlessEqual(info.bitrate, 65536)
 
     def test_underestimated_bitrate(self):
-        page = OggPage(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            page = OggPage(h)
         packet = page.packets[0]
         packet = (packet[:16] + b"\x00\x00\x01\x00" + b"\x01\x00\x00\x00" +
                   b"\x00\x00\x01\x00" + packet[28:])
         page.packets[0] = packet
-        info = OggVorbisInfo(cBytesIO(page.write()))
+        info = OggVorbisInfo(BytesIO(page.write()))
         self.failUnlessEqual(info.bitrate, 65536)
 
     def test_negative_bitrate(self):
-        page = OggPage(open(self.filename, "rb"))
+        with open(self.filename, "rb") as h:
+            page = OggPage(h)
         packet = page.packets[0]
         packet = (packet[:16] + b"\xff\xff\xff\xff" + b"\xff\xff\xff\xff" +
                   b"\xff\xff\xff\xff" + packet[28:])
         page.packets[0] = packet
-        info = OggVorbisInfo(cBytesIO(page.write()))
+        info = OggVorbisInfo(BytesIO(page.write()))
         self.failUnlessEqual(info.bitrate, 0)
 
     def test_vendor(self):
@@ -132,9 +134,9 @@ class TOggVorbis(TestCase, TOggFileTypeMixin):
 
     def test_not_my_ogg(self):
         fn = os.path.join(DATA_DIR, 'empty.oggflac')
-        self.failUnlessRaises(IOError, type(self.audio), fn)
-        self.failUnlessRaises(IOError, self.audio.save, fn)
-        self.failUnlessRaises(IOError, self.audio.delete, fn)
+        self.failUnlessRaises(error, type(self.audio), fn)
+        self.failUnlessRaises(error, self.audio.save, fn)
+        self.failUnlessRaises(error, self.audio.delete, fn)
 
     def test_save_split_setup_packet(self):
         fn = os.path.join(DATA_DIR, "multipage-setup.ogg")
