@@ -4,7 +4,7 @@ import os
 
 from tests.test_tools import _TTools
 
-from mutagen._toolsutil import fsnative as fsn
+from mutagen._senf import fsnative
 
 
 class TMutagenPony(_TTools):
@@ -12,7 +12,7 @@ class TMutagenPony(_TTools):
     TOOL_NAME = u"mutagen-pony"
 
     def test_basic(self):
-        base = os.path.join(fsn(u'tests'), fsn(u'data'))
+        base = os.path.join(fsnative(u'tests'), fsnative(u'data'))
         res, out = self.call(base)
         self.failIf(res)
         self.failUnless("Report for %s" % base in out)
